@@ -110,6 +110,7 @@ from processor.database.database import insert_one_document, sort_field, get_doc
     COLLECTION, DATABASE, DBNAME
 from processor.helper.httpapi.restapi_azure import json_source
 from processor.connector.snapshot_utils import validate_snapshot_nodes
+from processor.connector.snapshot_arm_template import populate_arm_snapshot
 
 
 logger = getlogger()
@@ -235,127 +236,6 @@ def get_all_nodes(repopath, node, snapshot, ref, connector):
     return db_records
 
 
-def populate_custom_snapshot_orig(snapshot):
-    """ Populates the resources from git."""
-    user_secret = None
-    dbname = config_value('MONGODB', 'dbname')
-    snapshot_source = get_field_value(snapshot, 'source')
-    sub_data = get_custom_data(snapshot_source)
-    snapshot_nodes = get_field_value(snapshot, 'nodes')
-    snapshot_data, valid_snapshotids = validate_snapshot_nodes(snapshot_nodes)
-    if valid_snapshotids and sub_data and snapshot_nodes:
-        giturl = get_field_value(sub_data, 'gitProvider')
-        ssh_file = get_field_value(sub_data, 'sshKeyfile')
-        brnch = get_field_value(sub_data, 'branchName')
-        username = get_field_value(sub_data, 'username')
-        if ssh_file:
-            if exists_file('%s/%s' % (os.environ['HOME'], ssh_file)):
-                ssh_key_file = '%s/%s' % (os.environ['HOME'], ssh_file)
-            elif exists_file('%s/.ssh/%s' % (os.environ['HOME'], ssh_file)):
-                ssh_key_file = '%s/.ssh/%s' % (os.environ['HOME'], ssh_file)
-            else:
-                ssh_key_file = None
-        else:
-            ssh_key_file = None
-        # if username:
-        #     user_secret = get_vault_data(username)
-        #     logger.info('Secret: %s', user_secret)
-        repopath = tempfile.mkdtemp()
-        logger.info("Repopath: %s", repopath)
-        exists, empty = valid_clone_dir(repopath)
-        if exists and empty:
-            try:
-                if ssh_key_file and exists_file(ssh_key_file):
-                    # restore, olddir, newdir, ssh_file = make_ssh_dir_before_clone(ssh_key_file)
-                    git_ssh_cmd = 'ssh -i %s' % ssh_key_file
-                    with Git().custom_environment(GIT_SSH_COMMAND=git_ssh_cmd):
-                        repo = Repo.clone_from(giturl, repopath, branch=brnch)
-                    # restore_ssh_dir_after_clone(restore, olddir, newdir)
-                else:
-                    # if username and user_secret:
-                    #    giturl = giturl.replace('https://', 'https://%s:%s@' %(username, user_secret))
-                    # elif username:
-                    #    giturl = giturl.replace('https://', 'https://%s@' % username)
-                    repo = Repo.clone_from(giturl, repopath, branch=brnch)
-            except Exception as ex:
-                logger.info('Unable to clone the repo: %s', ex)
-                repo = None
-            if repo:
-                for node in snapshot_nodes:
-                    logger.debug(node)
-                    data = get_node(repopath, node, snapshot, brnch, sub_data)
-                    if data:
-                        insert_one_document(data, data['collection'], dbname)
-                        snapshot_data[node['snapshotId']] = True
-                if os.path.exists(repopath):
-                    logger.info('Repo path: %s', repopath)
-                    shutil.rmtree(repopath)
-        # elif exists and not empty:
-        #     try:
-        #         Repo(repopath)
-        #         logger.info("A repository exists in this directory: %s", repopath)
-        #     except:
-        #         logger.info("A non-empty directory, clean it and run: %s", repopath)
-    return snapshot_data
-
-
-
-def valid_clone_dir(dirname):
-    if exists_dir(dirname):
-        exists = True
-        if not os.listdir(dirname):
-            empty = True
-        else:
-            empty = False
-    else:
-        exists = mkdir_path(dirname)
-        if exists and not os.listdir(dirname):
-            empty = True
-        else:
-            empty = False
-    return exists, empty
-
-
-def restore_ssh_dir_after_clone(restore, olddir, newdir):
-    if restore:
-        if exists_dir(olddir):
-            shutil.rmtree(newdir, ignore_errors=True)
-        if exists_dir(newdir):
-            os.rename(newdir, olddir)
-
-
-def make_ssh_dir_before_clone(ssh_key_file):
-    restore = False
-    newdir = None
-    olddir = None
-    ssh_file = None
-    if ssh_key_file and exists_file(ssh_key_file):
-        restore = True
-        tempdir = tempfile.mkdtemp()
-        # print(tempdir)
-        ssh_parts = ssh_key_file.rsplit('/', 1)
-        new_ssh_key_file = '%s/%s' % (tempdir, ssh_parts[-1])
-        # print(new_ssh_key_file)
-        shutil.copy(ssh_key_file, new_ssh_key_file)
-        olddir = '%s/.ssh' % os.environ['HOME']
-        # print(olddir)
-        if exists_dir(olddir):
-            newdir = '%s_old' % olddir
-            # print(newdir)
-            if exists_dir(newdir):
-                shutil.rmtree(newdir, ignore_errors=True)
-            os.rename(olddir, newdir)
-        os.mkdir(olddir)
-        ssh_file = '%s/id_rsa' % olddir
-        shutil.copy(new_ssh_key_file, ssh_file)
-        remove_file(new_ssh_key_file)
-        cfg = '%s/config' % olddir
-        with open(cfg, 'w') as f:
-            f.write('Host *\n')
-            f.write('    StrictHostKeyChecking no\n')
-    return restore, olddir, newdir, ssh_file
-
-
 def create_ssh_config(ssh_dir, ssh_key_file, ssh_user):
     ssh_config = '%s/config' % ssh_dir
     if exists_file(ssh_config):
@@ -519,45 +399,49 @@ def populate_custom_snapshot(snapshot, container=None):
         if repopath:
             brnch = get_field_value_with_default(sub_data, 'branchName', 'master')
             for node in snapshot_nodes:
-                # logger.debug(node)
-                # data = get_node(repopath, node, snapshot_source, brnch)
-                # if data:
-                #     insert_one_document(data, data['collection'], dbname)
-                #     snapshot_data[node['snapshotId']] = True
-                validate = node['validate'] if 'validate' in node else True
-                if 'snapshotId' in node:
-                    logger.debug(node)
-                    data = get_node(repopath, node, snapshot, brnch, sub_data)
-                    if data:
-                        if validate:
-                            if get_dbtests():
-                                insert_one_document(data, data['collection'], dbname)
+                node_type = node['type'] if 'type' in node and node['type'] else 'json'
+                if node_type == 'arm':
+                    populate_arm_snapshot(container, dbname, snapshot_source, sub_data, snapshot_data, node, repopath)
+                else:
+                    # logger.debug(node)
+                    # data = get_node(repopath, node, snapshot_source, brnch)
+                    # if data:
+                    #     insert_one_document(data, data['collection'], dbname)
+                    #     snapshot_data[node['snapshotId']] = True
+                    validate = node['validate'] if 'validate' in node else True
+                    if 'snapshotId' in node:
+                        logger.debug(node)
+                        data = get_node(repopath, node, snapshot, brnch, sub_data)
+                        if data:
+                            if validate:
+                                if get_dbtests():
+                                    insert_one_document(data, data['collection'], dbname)
+                                else:
+                                    snapshot_dir = make_snapshots_dir(container)
+                                    if snapshot_dir:
+                                        store_snapshot(snapshot_dir, data)
+                                if 'masterSnapshotId' in node:
+                                    snapshot_data[node['snapshotId']] = node['masterSnapshotId']
+                                else:
+                                    snapshot_data[node['snapshotId']] = True
                             else:
-                                snapshot_dir = make_snapshots_dir(container)
-                                if snapshot_dir:
-                                    store_snapshot(snapshot_dir, data)
-                            if 'masterSnapshotId' in node:
-                                snapshot_data[node['snapshotId']] = node['masterSnapshotId']
-                            else:
-                                snapshot_data[node['snapshotId']] = True
+                                snapshot_data[node['snapshotId']] = False
+                            node['status'] = 'active'
                         else:
-                            snapshot_data[node['snapshotId']] = False
-                        node['status'] = 'active'
-                    else:
-                        node['status'] = 'inactive'
-                    logger.debug('Type: %s', type(data))
-                elif 'masterSnapshotId' in node:
-                    alldata = get_all_nodes(repopath, node, snapshot, brnch, sub_data)
-                    if alldata:
-                        snapshot_data[node['masterSnapshotId']] = []
-                        for data in alldata:
-                            snapshot_data[node['masterSnapshotId']].append(
-                                {
-                                    'snapshotId': data['snapshotId'],
-                                    'path': data['path'],
-                                    'validate': True
-                                })
-                    logger.debug('Type: %s', type(alldata))
+                            node['status'] = 'inactive'
+                        logger.debug('Type: %s', type(data))
+                    elif 'masterSnapshotId' in node:
+                        alldata = get_all_nodes(repopath, node, snapshot, brnch, sub_data)
+                        if alldata:
+                            snapshot_data[node['masterSnapshotId']] = []
+                            for data in alldata:
+                                snapshot_data[node['masterSnapshotId']].append(
+                                    {
+                                        'snapshotId': data['snapshotId'],
+                                        'path': data['path'],
+                                        'validate': True
+                                    })
+                        logger.debug('Type: %s', type(alldata))
         if baserepo and os.path.exists(baserepo):
             logger.info('Repo path: %s', baserepo)
             shutil.rmtree(baserepo)
