@@ -185,6 +185,7 @@ def run_container_validation_tests_filesystem(container, snapshot_status=None):
             finalresult = False
     return finalresult
 
+
 def _get_snapshot_type_map(container):
     dbname = config_value(DATABASE, DBNAME)
     collection = config_value(DATABASE, collectiontypes[SNAPSHOT])
@@ -204,6 +205,7 @@ def _get_snapshot_type_map(container):
                             mappings[node['snapshotId']] = node['type']
     return mappings
 
+
 def run_container_validation_tests_database(container, snapshot_status=None):
     """ Get the test files from the database"""
     dbname = config_value(DATABASE, DBNAME)
@@ -293,4 +295,15 @@ def container_snapshots_filesystem(container):
             snapshot = test_json_data['snapshot'] if 'snapshot' in test_json_data else ''
             if snapshot:
                 snapshots.append(snapshot)
-    return snapshots
\ No newline at end of file
+    return snapshots
+
+def main(container):
+    run_container_validation_tests_filesystem(container)
+
+
+if __name__ == '__main__':
+    import sys
+    from processor.logging.log_handler import getlogger, init_logger, NONE
+    init_logger(NONE)
+    if len(sys.argv) > 1:
+        main(sys.argv[1])
\ No newline at end of file
